import os

from restrunner.conf import settings as Settings

def get_data_folder():
    return Settings.DATA_FOLDER

def create_data_folder(path):
    try:
        if not os.path.exists(path):
            os.makedirs(path)
            os.makedirs(path+"/log")
            open(path+"/commands.json", 'a').close()
            open(path+"/tasks.json", 'a').close()
        elif not os.path.exists(path+"/log"):
            path = path+"/log"
            os.makedirs(path)
            open(path+"/commands.json", 'a').close()
            open(path+"/tasks.json", 'a').close()
        else:
            if not os.path.exists(path+"/commands.json"):
                open(path+"/commands.json", 'a').close()
            if not os.path.exists(path+"/tasks.json"):
                open(path+"/tasks.json", 'a').close()
                
    except OSError as e:
        print(e)

def create_commands_template():
    pass



from flask_restful import Resource
from flask_restful import abort

from restrunner.common import db

def abort_doesnt_exist(name):
    """Abort request if doesnt exist."""
    abort(404, message=f"{name} doesn't exist")

class CommandList(Resource):
    """Flask Restfull class for getting command list."""
    def get(self):
        """Flask restfull standart get function."""
        command_list = db.get_all_commands()
        return command_list

class SearchTask(Resource):
    """Flask Restfull class for search task."""

    def get(self, status):
        """Flask restfull standart get function."""
        val = db.search_task(status)
        if val != 0 :
            return val
        else:
            abort_doesnt_exist(status)


"""Import tinydb, datetime, database"""
from subprocess import Popen
from datetime import datetime

# import database
from restrunner.common import db
from restrunner.conf import settings as Settings

def get_date_now():
    """Return time with speacial format for logging"""
    return datetime.today().strftime('%Y-%m-%d-%H-%M-%S')

def run(name, command):
    print(name+" basladi")
    date_now = get_date_now()
    log_file = Settings.DATA_FOLDER+"/log/"+date_now+"-"+name+".log"
    print(log_file)

    item = { 'sdate': date_now,
        'fdate': -1,
        'file': log_file,
        'name': name,
        'status': 2
    }
    log = open(log_file, 'a')
    log.write(date_now+' '+name+'\n')
    log.flush()
    proc = Popen(command, stdout=log, stderr=log, shell=True)
    proc_id = db.new_task(item)
    proc.wait()
    if proc.poll() == 0 :
        db.update_task(proc_id, "status", 1)
        db.update_task(proc_id, "fdate", get_date_now())
    else:
        db.update_task(proc_id, "status", 0)
        db.update_task(proc_id, "fdate", get_date_now())





PORT = 5000
DEBUG = False
HOST = "127.0.0.1"
DATA_FOLDER = ""

DEFAULT_COMMANDS = [
    {'name': 'test1', 'comment': 'tttttt', 'command': 'echo yusuf; echo duzgun'},
    {'name': 'test2', 'comment': 'wwwwww', 'command': 'erorrrrr'},
    {'name': 'test3', 'comment': 'long output', 'command': 'sleep 3; find ~; sleep3'}
]